@@ -230,7 +230,8 @@ class ExtendedMinimizer(object):
             save_title = "Result of fit of p.d.f. {} to dataset {}".format(self.name, data_name)
             print('INFO: ExtendedMinimizer::minimize("{}") saving results as {}'.format(self.name, save_name))
             self.fit_result = self.minimizer.save(save_name, save_title)
-        else:
+        # if the 'scan' option is used, minimizer will get deleted before this line
+        elif self.minimizer is not None:
             self.fit_result = self.minimizer.save()
 
         if self.cond_set.size() > 0:
