@@ -1,8 +1,12 @@
 import os
 import re
 import json
+import glob
+import datetime
 import difflib
 
+from quickstats.utils.common_utils import timely_info
+
 class NuisanceParameterHarmonizer(object):
     def __init__(self, ref_list=None):
         self.ref_list = ref_list
@@ -24,6 +28,7 @@ class NuisanceParameterHarmonizer(object):
         
     @staticmethod
     def get_nuiance_parameter_names_collection(ws_paths):
+        from quickstats.components import ExtendedModel
         nuis_names_collection = set()
         for ws_path in ws_paths:
             nuis_names = ExtendedModel.get_nuisance_parameter_names(ws_path)
@@ -180,6 +185,7 @@ class NuisanceParameterHarmonizer(object):
     def harmonize(self, ws_paths, outfile=None):
         if isinstance(ws_paths, str):
             ws_paths = [ws_paths]
+        timely_info('Harmonizing collective workspace files', ','.join(ws_paths))
         nuis_names = NuisanceParameterHarmonizer.get_nuiance_parameter_names_collection(ws_paths)
         harmonize_map = self.get_harmonize_map(nuis_names)
         if outfile is not None:
@@ -192,22 +198,26 @@ class NuisanceParameterHarmonizer(object):
             harmonize_map = self.harmonize(input_paths)
         elif isinstance(input_paths, dict):
             for k,v in input_paths.items():
-                harmonize_map[k] = self.harmonize(v)
+                harmonize_map[k] = self._harmonize_multi_input(v)
         return harmonize_map
     
     @staticmethod
     def get_input_paths(input_expr, base_path='./'):
         if isinstance(input_expr, str):
-            return glob.glob(os.path.join(base_path, input_expr))
+            full_path = os.path.join(base_path, input_expr)
+            ws_files = glob.glob(full_path)
+            if not ws_files:
+                print('WARNING: No matching input found in {}'.format(full_path))
+            return ws_files
         elif isinstance(input_expr, list):
             input_paths = []
             for expr in input_expr:
-                input_paths += get_input_paths(expr, base_path)
+                input_paths += NuisanceParameterHarmonizer.get_input_paths(expr, base_path)
             return input_paths
         elif isinstance(input_expr, dict):
             input_paths = {}
             for k,v in input_expr.items():
-                input_paths[k] = get_input_paths(v, base_path)
+                input_paths[k] = NuisanceParameterHarmonizer.get_input_paths(v, base_path)
             return input_paths
         else:
             raise ValueError('invalid input expr')
@@ -218,4 +228,5 @@ class NuisanceParameterHarmonizer(object):
         harmonize_map = self._harmonize_multi_input(input_paths)
         if outfile is not None:
             json.dump(harmonize_map, open(outfile, 'w'), indent=2)
+            timely_info('Saved rename output as ', ','.join(outfile))
         return harmonize_map
