@@ -1,9 +1,13 @@
 import sys
 import time
+import datetime
 import functools
 import multiprocessing
 from concurrent.futures  import ProcessPoolExecutor
 
+def timely_info(green_text, normal_text, adjust=40):
+    print(datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S'), '\033[92m[INFO]\033[0m', '\033[92m{}\033[0m'.format(green_text).rjust(40, ' '), normal_text)
+
 def get_cpu_count():
     return multiprocessing.cpu_count()
 
